@@ -5,6 +5,8 @@
 #' to allow forms such as "Sepal.Length >= 2 * Sepal.Width".
 #' (without the quotes).
 #'
+#' qe() uses bquote() .() quasiquotation escaping notation.
+#'
 #' @param ... assignment expressions.
 #' @return array of quoted assignment expressions.
 #'
@@ -12,14 +14,25 @@
 #'
 #' @examples
 #'
+#' ratio <- 2
+#'
 #' exprs <- qe(Sepal.Length >= ratio * Sepal.Width,
 #'              Petal.Length <= 3.5)
 #' print(exprs)
+#'
+#' exprs <- qe(Sepal.Length >= .(ratio) * Sepal.Width,
+#'              Petal.Length <= 3.5)
+#' print(exprs)
+
 #'
 #' @export
 #'
 qe <- function(...) {
-  e_terms <- substitute(list(...))
+  #e_terms <- substitute(list(...))
+  .wrapr_private_var_env <- parent.frame()
+  e_terms <- do.call(bquote, list(substitute(list(...)),
+                                   where = .wrapr_private_var_env),
+                     envir = .wrapr_private_var_env)
   if(length(setdiff(names(e_terms), ""))>0) {
     stop("wrapr::qe() unexpected names/arguments")
   }
@@ -44,6 +57,8 @@ qe <- function(...) {
 #' (without the quotes).
 #' Terms are expressions of the form "lhs := rhs", "lhs = rhs", "lhs \%:=\% rhs".
 #'
+#' qae() uses bquote() .() quasiquotation escaping notation.
+#'
 #' @param ... assignment expressions.
 #' @return array of quoted assignment expressions.
 #'
@@ -51,10 +66,16 @@ qe <- function(...) {
 #'
 #' @examples
 #'
+#' ratio <- 2
+#'
 #' exprs <- qae(Sepal_Long := Sepal.Length >= ratio * Sepal.Width,
 #'              Petal_Short = Petal.Length <= 3.5)
 #' print(exprs)
-#' #ratio <- 2
+#'
+#' exprs <- qae(Sepal_Long := Sepal.Length >= .(ratio) * Sepal.Width,
+#'              Petal_Short = Petal.Length <= 3.5)
+#' print(exprs)
+#'
 #' #datasets::iris %.>%
 #' #  seplyr::mutate_se(., exprs) %.>%
 #' #  summary(.)
@@ -64,7 +85,11 @@ qe <- function(...) {
 qae <- function(...) {
   # convert char vector into spliceable vector
   # from: https://github.com/tidyverse/rlang/issues/116
-  ae_terms <- substitute(list(...))
+  #ae_terms <- substitute(list(...))
+  .wrapr_private_var_env <- parent.frame()
+  ae_terms <- do.call(bquote, list(substitute(list(...)),
+                                   where = .wrapr_private_var_env),
+                      envir = .wrapr_private_var_env)
   # ae_terms is a list of k+1 items, first is "list" the rest are captured expressions
   len <- length(ae_terms) # first slot is "list"
   if(len<=1) {
@@ -95,7 +120,7 @@ qae <- function(...) {
       }
     }
     if(is.null(ni)) {
-      stop("seplyr::quote_mutate terms must all have names (either from =, :=, or %:=%)")
+      stop("seplyr::qae terms must all have names (either from =, :=, or %:=%)")
     }
     lhs[[i-1]] <- ni
     rhs[[i-1]] <- vi
@@ -106,16 +131,25 @@ qae <- function(...) {
 
 #' Quote argument as a string.
 #'
+#' qs() uses bquote() .() quasiquotation escaping notation.
+#'
 #' @param s expression to be quoted as a string.
 #' @return character
 #'
 #' @examples
 #'
-#' qs(a == "x")
+#' x <- 7
+#'
+#' qs(a == x)
+#'
+#' qs(a == .(x))
 #'
 #' @export
 #'
 qs <- function(s) {
-  # as.character(paste(deparse(substitute(s)), collapse = '\n'))
-  wrapr_deparse(substitute(s))
+  # wrapr_deparse(substitute(s))
+  .wrapr_private_var_env <- parent.frame()
+  do.call(bquote, list(substitute(s),
+                       where = .wrapr_private_var_env),
+          envir = .wrapr_private_var_env)
 }
