@@ -9,7 +9,7 @@ cos(exp(sin(4)))
 1:4 %.>% .^2 
 
 ## ----pipe2---------------------------------------------------------------
-1:4 %.>% { .^2 } 
+5 %.>% sin(.)
 
-1:4 %.>% ( .^2 )
+5 %.>% base::sin(.)
 
